﻿<?php
/**
 * 2007-2016 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2016 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 **/
class Mail365API {

	private $apikey;
	private $apiURL = 'https://api.mail365.ru';

	/** 
	 * Конструктор класса. К качестве параметра нужно указать API-ключ,
	 * который можно получить в личном кабинете.
	 */
	public function __construct($apikey) {

		$this->apikey = $apikey;
	
	}
	
	/**
	 * Вспомогательный метод для формирования GET запроса
	 */
	private function createGetRequest ($URL) {
	
		$ch = curl_init();
		
		curl_setopt($ch, CURLOPT_URL, $URL);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
  
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(  
			'Accept: application/json',  
			'Content-Type: application/json',  
			'Authorization: ApiKey '.$this->apikey));  

		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
	
		return $ch;
			
	}
	
	/**
	 * Вспомогательный метод для формирования POST запроса
	 */
	private function createPostRequest ($URL, $postdata) {
			
		$ch = curl_init();

		curl_setopt($ch, CURLOPT_URL, $URL);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_POST, 1);  
  
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(  
			'Accept: application/json',  
			'Content-Type: application/json',  
			'Authorization: ApiKey '.$this->apikey));  
		
		curl_setopt($ch, CURLOPT_POSTFIELDS, Tools::jsonEncode($postdata));  
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
			
		return $ch;
	}
	
	/** 
	 * Вспомогательный метод для формирования PUT запроса
	 */
	private function createPutRequest ($URL, $postdata) {
		
		$ch = curl_init();
		
		curl_setopt($ch, CURLOPT_URL, $URL);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);  
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);  
		curl_setopt($ch, CURLOPT_PUT, 0);  
		
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(  
			'Accept: application/json',  
			'Content-Type: application/json',  
			'Authorization: ApiKey '.$this->apikey));  
		
		curl_setopt($ch, CURLOPT_POSTFIELDS, Tools::jsonEncode($postdata));  
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);  
		
		return $ch;
		
	}
	
	/**
	 * Вспомогательный метод для формирования DELETE запроса
	 */
	private function createDeleteRequest ($URL) {
	
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $URL);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);  
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);  
		
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(  
			'Accept: application/json',  
			'Content-Type: application/json',  
			'Authorization: ApiKey '.$this->apikey));  
		
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);  
		
		return $ch;
		
	}
	
	/**
	 * Вспомогательный метод для отправки запроса
	 */
	private function sendRequest ($ch) {
		
		$response = curl_exec ($ch);  
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		
		curl_close ($ch); 
		
		return $this->parseResponse($http_code, $response);
		
	}
	
	/**
	 * Вспомогательный метод для формирования ответа в виде ассоциативного массива
	 */
	private function parseResponse ($http_code, $response) {
	
		$p_response = Tools::jsonDecode($response, TRUE);
		
		if (empty($p_response)) {
			$p_response = array('http_code' => $http_code);
		} else {
			if (is_array($p_response)) {
				$p_response = array('http_code' => $http_code) + $p_response;
			} else {
				$p_response = array(
					'http_code' => $http_code,
					'response' => $p_response
				);
			}
		}
		
		return $p_response;
		
	}
	
	/**
	 * Получить информацию о группах контактов в порядке их создания
	 *
	 * @param string SearchQuery		Поисковая фраза
	 * @param uint32 Offset 			Количество начальных элементов в результате, которые надо пропустить
	 * @param uint32 Limit 				Количество элементов, которые необходимо вернуть (максимум — 500, по умолчанию — 50)
	 * @param boolean IncludeStatistics	True, если следует включать в ответ статистику по группе
	 * @param boolean IncludeFilters	True, если следует включать в ответ фильтры группы
	 * @param boolean IncludeColumns 	True, если следует включать в результат колонки группы	
	 *
	 * @return array
	 */
	public function getContactGroups ($SearchQuery, $Offset, $Limit, $IncludeStatistics, $IncludeFilters, $IncludeColumns) {
	
		$URL = $this->apiURL . '/contactGroups?searchquery=' . $SearchQuery . '&Offset=' . $Offset . '&Limit=' . $Limit .
			   '&includestatistics=' . $IncludeStatistics . '&includefilters=' . $IncludeFilters . '&IncludeColumns=' . $IncludeColumns;
			   
		$ch = $this->createGetRequest($URL);
		
		$response = $this->sendRequest($ch);
		
		return $response;
	
	}

	/**
	 * Добавить в группу новый контакт
	 *
	 * @param string Id 	Идентификатор группы контактов. Идентификатор можно получить, выполнив запрос GET /ContactGroups
	 * @param array Data 	Данные контакта, передаются в виде словаря. Словарь должен из себя представлять ассоциативный массив вида array("Имя" => "Антон", "Номер телефона" => "79214571245");
	 *
	 * @return array 
	 */
	public function postContactGroupsIdContacts ($Id, $Data) {
	
		$postdata = array(
			'Data' => $Data
		);
		
		$URL = $this->apiURL . '/contactGroups/' . $Id . '/contacts';
	
		$ch = $this->createPostRequest($URL, $postdata);
	
		$response = $this->sendRequest($ch);
		
		return $response;
	
	}

	/**
	 * Получить email-адреса отправителя в алфавитном порядке
	 *
	 * @param uint32 Offset Количество начальных элементов в результате, которые надо пропустить
	 * @param uint32 Limit	Количество элементов, которые необходимо вернуть (максимум — 500, по умолчанию — 50)
	 *
	 * @return array
	 */
	public function getEmailAddresses ($Offset, $Limit) {
	
		$URL = $this->apiURL . '/emailAddresses?offset=' . $Offset . '&Limit=' . $Limit;
		
		$ch = $this->createGetRequest($URL);
		
		$response = $this->sendRequest($ch);
		
		return $response;
	
	}

	/**
	 * Получить заверенные имена отправителя SMS (Sender ID) в алфавитном порядке
	 *
	 * @param uint32 Offset 	Количество начальных элементов в результате, которые надо пропустить
	 * @param uint32 Limit 		Количество элементов, которые необходимо вернуть (максимум — 500, по умолчанию — 50)
	 *
	 * @return array
	 */
	public function getSmsSenderIds ($Offset, $Limit) {
	
		$URL = $this->apiURL . '/smsSenderIds?offset=' . $Offset . '&Limit=' . $Limit;
		
		$ch = $this->createGetRequest($URL);
		
		$response = $this->sendRequest($ch);
		
		return $response;
		
	}

	/**
	 * Отправить одиночное Email-сообщение
	 *
	 * @param string Subject 		Тема Email	
	 * @param string Body 			Тело Email
	 * @param string FromAddress 	Email-адрес отправителя (должен быть в перечне разрешенных адресов в профиле)
	 * @param string ToAddress 		Email-адрес получателя
	 *
	 * @return array
	 */
	public function postSingleEmail ($Subject, $Body, $FromAddress, $ToAddress) {
		
		$postdata = array(
			'Subject' => $Subject,
			'Body' => $Body,
			'FromAddress' => $FromAddress,
			'ToAddress' => $ToAddress
		);
		
		$URL = $this->apiURL . '/singleEmail';
		
		$ch = $this->createPostRequest($URL, $postdata);
		
		$response = $this->sendRequest($ch);
		
		return $response;
	
	}

	/**
	 * Отправить одиночное СМС-сообщение
	 *
	 * @param string SenderId 				Имя отправителя СМС
	 * @param string SendDateTime 			Дата и время, в которое следует отправить СМС. Оставьте пустым для немедленной отправки. 
	 *										При UseRecepientTimeZone = True укажите здесь время в часовой зоне абонента. Иначе укажите здесь время UTC
	 * @param boolean UseRecepientTimeZone 	True, если следует отправлять СМС по местному времени абонента	
	 * @param string PhoneNumber 			Номер телефона, на который нужно отправить сообщение
	 * @param string Text 					Текст СМС
	 *
	 * @return array
	 */
	public function postSingleSms ($SenderId, $SendDateTime, $UseRecepientTimeZone, $PhoneNumber, $Text) {
		  
		$postdata = array(  
			'SenderId' => $SenderId,  
			'SendDateTime' => $SendDateTime,
			'UseRecepientTimeZone' => $UseRecepientTimeZone,
			'PhoneNumber' => $PhoneNumber,     
			'Text' => $Text              
		);  
		
		$URL = $this->apiURL . '/SingleSms';
  
		$ch = $this->createPostRequest($URL, $postdata);
  
		$response = $this->sendRequest($ch);
  
		return $response;
		
	}

}
?>