<?php
/**
 * 2007-2016 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2016 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 **/
include(dirname(__FILE__).'/Mail365API.php');	
	
if (!defined('_PS_VERSION_')) exit;
	
class Mail365 extends Module
{
	private $_html = '';
	private $tab_active = '';
	public function __construct()
	{
		$this->name = 'mail365';
		$this->tab = 'advertising_marketing';
		$this->version = '1.4.0';
		$this->author = 'Vendosoft';
		$this->need_instance = 0;
		$this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_); 
		$this->bootstrap = true;

		parent::__construct();
 
		$this->displayName = $this->l('Модуль Mail365');
		$this->description = $this->l('Сервис email маркетинга с классным редактором, автоматизацией, отличной доставляемостью, эффективными формами подписки и приятными ценами в рублях.');
	
		$this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
	}
	
	public function install()
	{
		if (Shop::isFeatureActive()) Shop::setContext(Shop::CONTEXT_ALL);
 
		if (!parent::install()) return false;
 
		return $this->registerHook('newOrder') && 
           $this->registerHook('updateOrderStatus') && 
           $this->registerHook('createAccount') && 
           $this->registerHook('actionPaymentConfirmation') &&
           $this->registerHook('actionAdminOrdersTrackingNumberUpdate');
	}
	
	public function uninstall()
	{
		if (!parent::uninstall()) return false;
	
		return true;
	}
	
	public function getContent()
	{
		$this->_postProcess();
		$this->_displayForm();
		return $this->_html;
	}
	
	private function _postProcess()
	{
		if (Tools::isSubmit('save_mail365_api_key')) {
			Configuration::updateValue('mail365_api_key', Tools::getValue('mail365_api_key'));
			$this->_html .= $this->displayConfirmation($this->l('Настройки обновлены.'));
		}
		
		if (Tools::isSubmit('save_settings_sms_tab')) {
			Configuration::updateValue('mail365_sender_id', Tools::getValue('mail365_sender_id'));
			Configuration::updateValue('mail365_send_time', Tools::getValue('mail365_send_time'));
			$this->tab_active = 'sms';
			$this->_html .= $this->displayConfirmation($this->l('Настройки обновлены.'));
		}
		
		if (Tools::isSubmit('save_settings_email_tab')) {
			Configuration::updateValue('mail365_email_address', Tools::getValue('mail365_email_address'));
			Configuration::updateValue('mail365_subject', Tools::getValue('mail365_subject'));
			$this->tab_active = 'email';
			$this->_html .= $this->displayConfirmation($this->l('Настройки обновлены.'));
		}
		
		if (Tools::isSubmit('save_settings_sms_tab_patterns')) {
			Configuration::updateValue('mail365_sms_patterns', Tools::jsonEncode(Tools::getValue('patterns')));
			$this->tab_active = 'sms';
			$this->_html .= $this->displayConfirmation($this->l('Настройки обновлены.'));
		}
		
		if (Tools::isSubmit('save_settings_email_tab_patterns')) {
			$patterns = Tools::getValue('patterns');
			foreach ($patterns as $key => $pattern) {
				$patterns[$key] = htmlentities($pattern);
			}
			Configuration::updateValue('mail365_email_patterns', Tools::jsonEncode($patterns));
			$this->tab_active = 'email';
			$this->_html .= $this->displayConfirmation($this->l('Настройки обновлены.'));
		}
		
		if (Tools::isSubmit('import_contacts')) {
			$result = $this->importContacts(Tools::getValue('mail365_import_id_shop'), Tools::getValue('mail365_import_contact_group'));
			$this->tab_active = 'import';
			if ($result["error"] == 0) {
				$message = 'Импорт успешно завершен. ' . $this->trueWordFormImport($result["all_contacts"]) . ' ' . $result["all_contacts"] . ' ' . $this->trueWordFormContacts($result["all_contacts"]) . '.';
				$this->_html .= $this->displayConfirmation($this->l($message));
			} else {
				$message = 'Импорт успешно завершен. Импортировано ' . $result["all_contacts"] . ' ' . $this->trueWordFormContacts($result["all_contacts"]) . '. '
							. max(count($result["phones"]), count($result["emails"])) . ' ' . $this->trueWordFormContacts(count($result["phones"]), count($result["emails"])) . 
							' ранее ' . $this->trueWordFormBe(count($result["phones"]), count($result["emails"])) . ' ' . $this->trueWordFormImport(count($result["phones"]), count($result["emails"])) . '.';
				$this->_html .= $this->displayConfirmation($this->l($message));
			}
		}
		
		if (Tools::isSubmit('autoimport_contacts')) {
			Configuration::updateValue('mail365_autoimport_contact_groups', Tools::jsonEncode(Tools::getValue('mail365_autoimport_contact_groups')));
			$this->tab_active = 'autoimport';
			$this->_html .= $this->displayConfirmation($this->l('Данные для автоимпорта успешно сохранены'));
		}	
	}
	
	public function _displayForm()
	{
		$mail365_api_key = Tools::getValue('mail365_api_key', Configuration::get('mail365_api_key'));
		
		$this->_html .= '<link rel="stylesheet" href="' . $this->_path . 'views/css/style.css">';
		$this->_html .= '<script src="' . $this->_path . 'views/js/script.js"></script>';
	
		$this->_html .='
		<form id="save_mail365_api_key" action="' .$_SERVER['REQUEST_URI']. '" method="post" style="padding: 5px 0px; border-bottom: 1px solid #e5e5e5;">
		<fieldset>
			<legend>' . $this->l('Укажите API ключ') . '</legend>
				<label for="mail365_api_key">' . $this->l('API-ключ') . '</label>
				<div class="item_form_settings api_key">
					<input type="text" name="mail365_api_key" value="' . $mail365_api_key . '" />
					<div class="error"></div>
				</div>
				<div class="item_form_settings api_key">
					<input class="mail365_button" type="submit" name="save_mail365_api_key" value="' . $this->l('Сохранить') . '"/>
				</div>
			</fieldset>
		</form>
		';
		
		if (isset($mail365_api_key) && !empty($mail365_api_key)) {
			
			$mail365_api = new Mail365API($mail365_api_key);
	
			$this->_html .= '<div id="tabs" class="tabs">';
			
			$this->_html .= '<input class="mail365_tabs" type="radio" name="tab"';
			$this->_html .= ($this->tab_active == 'sms') ? ' checked="checked" id="tab_sms"/>' : ' id="tab_sms"/>';
			$this->_html .= '<label class="mail365_label_for_tab" for="tab_sms">Смс оповещения</label>';
			
			$this->_html .= '<input class="mail365_tabs" type="radio" name="tab"';
			$this->_html .= ($this->tab_active == 'email') ? ' checked="checked" id="tab_email"/>' : ' id="tab_email"/>';
			$this->_html .= '<label class="mail365_label_for_tab" for="tab_email">Email оповещения</label>';
			
			$this->_html .= '<input class="mail365_tabs" type="radio" name="tab"';
			$this->_html .= ($this->tab_active == 'import') ? ' checked="checked" id="tab_import_contacts"/>' : ' id="tab_import_contacts"/>';
			$this->_html .= '<label class="mail365_label_for_tab" for="tab_import_contacts">Импорт</label>';
			
			$this->_html .= '<input class="mail365_tabs" type="radio" name="tab"';
			$this->_html .= ($this->tab_active == 'autoimport') ? ' checked="checked" id="tab_autoimport_contacts"/>' : ' id="tab_autoimport_contacts"/>';
			$this->_html .= '<label class="mail365_label_for_tab" for="tab_autoimport_contacts">Автоимпорт</label>';
			
			$this->renderSmsTab($mail365_api);
			$this->renderEmailTab($mail365_api);
			$this->renderImportTab($mail365_api);
			$this->renderAutoImportTab($mail365_api);
			
			$this->_html .= '</div>';
			
		}
	}
	
	private function renderSmsTab($mail365_api) 
	{
		$sender_ids = $mail365_api->getSmsSenderIds("0", "500");
		$html_sender_ids = '';
		if ($sender_ids["http_code"] == 200) {
			foreach ($sender_ids["items"] as $sender_id) {
				if ($sender_id == Configuration::get('mail365_sender_id')) {
					$html_sender_ids .= '<option value="' . $sender_id . '" selected>' . $sender_id . '</option>';
				} else {
					$html_sender_ids .= '<option value="' . $sender_id .'">' . $sender_id . '</option>';
				}
			}
		}
			
		$sent_time_first_item = 10;
		if (Configuration::get('mail365_send_time') == 'NULL') {
			$html_sent_time = '<option value="NULL" selected>Не указано</option>';
		} else {
			$html_sent_time = '<option value="NULL">Не указано</option>';
		}
		for ($i = 0; $i < 11; $i++) {
			if ($sent_time_first_item + $i == Configuration::get('mail365_send_time')) {
				$html_sent_time .= '<option value="' . (string)($sent_time_first_item + $i).'" selected>' . (string)($sent_time_first_item + $i) . ':00</option>';
			} else {
				$html_sent_time .= '<option value="' . (string)($sent_time_first_item + $i) . '">' . (string)($sent_time_first_item + $i) . ':00</option>';
			}
		}
				
		$this->_html .= '
		<div>
			<form action="' .$_SERVER['REQUEST_URI']. '" method="post">
				<fieldset>
					<legend>' . $this->l('Настройки смс оповещений') . '</legend>
					<label for="mail365_sender_id">' . $this->l('Выберите имя отправителя') . '</label>
					<div class="item_form_settings settings_sms">
						<select name="mail365_sender_id">
							' . $html_sender_ids . '
						</select>
					</div>
					<label for="mail365_send_time">' . $this->l('Выберите время отправки') . '</label>
					<div class="item_form_settings settings_sms">
						<select name="mail365_send_time">
							' . $html_sent_time . ' 
						</select>
					</div>
					<div class="item_form_settings settings_sms">
						<input class="mail365_button" type="submit" name="save_settings_sms_tab" value="' . $this->l('Сохранить') . '"/>
					</div>
				</fieldset>
			</form>';
			
		$order_states = OrderState::getOrderStates((int)Configuration::get('PS_LANG_DEFAULT'));
		$mail365_sms_patterns = Tools::jsonDecode(Configuration::get('mail365_sms_patterns'), TRUE);
		
    $pattern_text = (!empty($mail365_sms_patterns['sms_new'])) ? $mail365_sms_patterns['sms_new'] : '';	
		$this->_html .= '
			<form action="' .$_SERVER['REQUEST_URI']. '" method="post" style="margin-top: 30px;">
				<fieldset>
					<legend>' . $this->l('Настройки шаблонов для смс оповещений') . '</legend>
					<label for="statusNew">' . $this->l('Смс после создания заказа') . '</label>
					<div>
						<div class="textarea">
							<textarea name="patterns[sms_new]">' . $pattern_text . '</textarea>
						</div>
						<div class="variables">
              <p><strong>{shop_name}</strong> - название магазина,</p>
							<p><strong>{date}</strong> - дата/время создания заказа,</p>
							<p><strong>{order}</strong> - номер заказа,</p>
              <p><strong>{order_reference}</strong> - код заказа,</p>
							<p><strong>{sum}</strong> - сумма заказа,</p>
							<p><strong>{user_name}</strong> - имя клиента,</p>
							<p><strong>{status}</strong> - статус заказа,</p>
							<p><strong>{delivery_description}</strong> - способ доставки,</p>
							<p><strong>{full_delivery_address}</strong> - адрес доставки</p>
						</div>
					</div>
					<hr>';
					
		foreach ($order_states as $order_state) {
			if (!$order_state["deleted"]) {
        $pattern_text = (!empty($mail365_sms_patterns['sms_' . $order_state["id_order_state"]])) ? $mail365_sms_patterns['sms_' . $order_state["id_order_state"]] : '';
				$this->_html .= '
					<label for="status' . $order_state["id_order_state"] . '">' . $this->l('Шаблон для статуса "' . $order_state['name'] . '"') . '</label>
					<div>
						<div class="textarea">
							<textarea name="patterns[sms_' . $order_state["id_order_state"] . ']">' . $pattern_text . '</textarea>
						</div>
						<div class="variables">
              <p><strong>{shop_name}</strong> - название магазина,</p>
							<p><strong>{date}</strong> - дата/время создания заказа,</p>
							<p><strong>{order}</strong> - номер заказа,</p>
              <p><strong>{order_reference}</strong> - код заказа,</p>
							<p><strong>{sum}</strong> - сумма заказа,</p>
							<p><strong>{user_name}</strong> - имя клиента,</p>
							<p><strong>{status}</strong> - статус заказа,</p>
							<p><strong>{delivery_description}</strong> - способ доставки,</p>
							<p><strong>{full_delivery_address}</strong> - адрес доставки</p>
						</div>
					</div>
					<hr>
				';
			}
		}
    
    $pattern_text = (!empty($mail365_sms_patterns['sms_payment_confirm'])) ? $mail365_sms_patterns['sms_payment_confirm'] : '';
    $this->_html .= '
			<label for="statusPaymentConfirm">' . $this->l('Смс после подтверждения платежа') . '</label>
			<div>
				<div class="textarea">
					<textarea name="patterns[sms_payment_confirm]">' . $pattern_text . '</textarea>
				</div>
				<div class="variables">
          <p><strong>{shop_name}</strong> - название магазина,</p>
					<p><strong>{date}</strong> - дата/время создания заказа,</p>
					<p><strong>{order}</strong> - номер заказа,</p>
          <p><strong>{order_reference}</strong> - код заказа,</p>
					<p><strong>{sum}</strong> - сумма заказа,</p>
					<p><strong>{user_name}</strong> - имя клиента,</p>
					<p><strong>{status}</strong> - статус заказа,</p>
					<p><strong>{delivery_description}</strong> - способ доставки,</p>
					<p><strong>{full_delivery_address}</strong> - адрес доставки</p>
				</div>
			</div>
			<hr>
		';
    
    $pattern_text = (!empty($mail365_sms_patterns['sms_admin_orders_tracking_number_update'])) ? $mail365_sms_patterns['sms_admin_orders_tracking_number_update'] : '';
    $this->_html .= '
			<label for="statusAdminOrdersTrackingNumberUpdate ">' . $this->l('Смс после обновления номера отслеживания') . '</label>
			<div>
				<div class="textarea">
					<textarea name="patterns[sms_admin_orders_tracking_number_update]">' . $pattern_text . '</textarea>
				</div>
				<div class="variables">
          <p><strong>{shop_name}</strong> - название магазина,</p>
					<p><strong>{date}</strong> - дата/время создания заказа,</p>
					<p><strong>{order}</strong> - номер заказа,</p>
          <p><strong>{order_reference}</strong> - код заказа,</p>
					<p><strong>{sum}</strong> - сумма заказа,</p>
					<p><strong>{user_name}</strong> - имя клиента,</p>
					<p><strong>{status}</strong> - статус заказа,</p>
					<p><strong>{delivery_description}</strong> - способ доставки,</p>
					<p><strong>{full_delivery_address}</strong> - адрес доставки,</p>
          <p><strong>{track_number}</strong> - номер отслеживания</p>
          <p><strong>{tracking_url}</strong> - URL для отслеживания</p>
				</div>
			</div>
			<hr>
		';	
			
		$this->_html .= '
					<div>
						<input class="mail365_button" type="submit" name="save_settings_sms_tab_patterns" value="' . $this->l('Сохранить') . '"/>
					</div>
				</fieldset>
			</form>
		</div>';
	}
	
	private function renderEmailTab($mail365_api) 
	{		
		$html_email_addresses = '';
		
		$email_addresses = $mail365_api->getEmailAddresses("0", "500");
		
		foreach ($email_addresses["items"] as $email_address) {
			if ($email_address["email"] == Configuration::get('mail365_email_address')) {
				$html_email_addresses .= '<option value="' . $email_address["email"] . '" selected>' . $email_address["name"] . ' &lt;' . $email_address["email"] . '&gt;</option>';
			} else {
				$html_email_addresses .= '<option value="' . $email_address["email"] . '">' . $email_address["name"] . ' &lt;' . $email_address["email"] . '&gt;</option>';
			}
		}
		
		$this->_html .= '
		<div>
			<form id="save_settings_email_tab" action="' .$_SERVER['REQUEST_URI']. '" method="post">
				<fieldset>
					<legend>' . $this->l('Настройки email оповещений') . '</legend>
					<label for="mail365_email_address">' . $this->l('Выберите адрес отправителя') . '</label>
					<div class="item_form_settings settings_email">
						<select name="mail365_email_address">
							' . $html_email_addresses . '
						</select>
					</div>
					<label for="mail365_subject">' . $this->l('Введите тему писем') . '</label>
					<div class="item_form_settings settings_email">
						<input type="text" name="mail365_subject" value="' . Configuration::get('mail365_subject') .'"/>
						<div class="error"></div>
					</div>
					<div class="item_form_settings settings_email">
						<input class="mail365_button" type="submit" name="save_settings_email_tab" value="' . $this->l('Сохранить') . '"/>
					</div>
				</fieldset>
			</form>';
		
		$order_states = OrderState::getOrderStates((int)Configuration::get('PS_LANG_DEFAULT'));
		$mail365_email_patterns = Tools::jsonDecode(Configuration::get('mail365_email_patterns'), TRUE);
		
    $pattern_text = (!empty($mail365_email_patterns['email_new'])) ? $mail365_email_patterns['email_new'] : '';	
		$this->_html .= '
			<form action="' .$_SERVER['REQUEST_URI']. '" method="post" style="margin-top: 30px;">
				<fieldset>
					<legend>' . $this->l('Настройки шаблонов для email оповещений') . '</legend>
					<label for="statusNew">' . $this->l('Письмо после создания заказа') . '</label>
					<div>
						<div class="textarea">
							<textarea name="patterns[email_new]">' . $pattern_text . '</textarea>
						</div>
						<div class="variables">
              <p><strong>{shop_name}</strong> - название магазина,</p>
							<p><strong>{date}</strong> - дата/время создания заказа,</p>
							<p><strong>{order}</strong> - номер заказа,</p>
              <p><strong>{order_reference}</strong> - код заказа,</p>
							<p><strong>{sum}</strong> - сумма заказа,</p>
							<p><strong>{user_name}</strong> - имя клиента,</p>
							<p><strong>{status}</strong> - статус заказа,</p>
							<p><strong>{delivery_description}</strong> - способ доставки,</p>
							<p><strong>{full_delivery_address}</strong> - адрес доставки</p>
						</div>
					</div>
					<hr>';
          
		foreach ($order_states as $order_state) {
			if (!$order_state["deleted"]) {
        $pattern_text = (!empty($mail365_email_patterns['email_' . $order_state["id_order_state"]])) ? $mail365_email_patterns['email_' . $order_state["id_order_state"]] : '';	
				$this->_html .= '
					<label for="status' . $order_state["id_order_state"] . '">' . $this->l('Шаблон для статуса "' . $order_state['name'] . '"') . '</label>
					<div>
						<div class="textarea">
							<textarea name="patterns[email_' . $order_state["id_order_state"] . ']">' . $pattern_text . '</textarea>
						</div>
						<div class="variables">
              <p><strong>{shop_name}</strong> - название магазина,</p>
							<p><strong>{date}</strong> - дата/время создания заказа,</p>
							<p><strong>{order}</strong> - номер заказа,</p>
              <p><strong>{order_reference}</strong> - код заказа,</p>
							<p><strong>{sum}</strong> - сумма заказа,</p>
							<p><strong>{user_name}</strong> - имя клиента,</p>
							<p><strong>{status}</strong> - статус заказа,</p>
							<p><strong>{delivery_description}</strong> - способ доставки,</p>
							<p><strong>{full_delivery_address}</strong> - адрес доставки</p>
						</div>
					</div>
					<hr>
				';
			}
		}
    
    $pattern_text = (!empty($mail365_email_patterns['email_payment_confirm'])) ? $mail365_email_patterns['email_payment_confirm'] : '';
    $this->_html .= '
			<label for="statusPaymentConfirm">' . $this->l('Письмо после подтверждения платежа') . '</label>
			<div>
				<div class="textarea">
					<textarea name="patterns[email_payment_confirm]">' . $pattern_text . '</textarea>
				</div>
				<div class="variables">
          <p><strong>{shop_name}</strong> - название магазина,</p>
					<p><strong>{date}</strong> - дата/время создания заказа,</p>
					<p><strong>{order}</strong> - номер заказа,</p>
          <p><strong>{order_reference}</strong> - код заказа,</p>
					<p><strong>{sum}</strong> - сумма заказа,</p>
					<p><strong>{user_name}</strong> - имя клиента,</p>
					<p><strong>{status}</strong> - статус заказа,</p>
					<p><strong>{delivery_description}</strong> - способ доставки,</p>
					<p><strong>{full_delivery_address}</strong> - адрес доставки</p>
				</div>
			</div>
			<hr>
		';
    
    $pattern_text = (!empty($mail365_email_patterns['email_admin_orders_tracking_number_update'])) ? $mail365_email_patterns['email_admin_orders_tracking_number_update'] : '';
    $this->_html .= '
			<label for="statusAdminOrdersTrackingNumberUpdate">' . $this->l('Письмо после обновления номера отслеживания') . '</label>
			<div>
				<div class="textarea">
					<textarea name="patterns[email_admin_orders_tracking_number_update]">' . $pattern_text . '</textarea>
				</div>
				<div class="variables">
          <p><strong>{shop_name}</strong> - название магазина,</p>
					<p><strong>{date}</strong> - дата/время создания заказа,</p>
					<p><strong>{order}</strong> - номер заказа,</p>
          <p><strong>{order_reference}</strong> - код заказа,</p>
					<p><strong>{sum}</strong> - сумма заказа,</p>
					<p><strong>{user_name}</strong> - имя клиента,</p>
					<p><strong>{status}</strong> - статус заказа,</p>
					<p><strong>{delivery_description}</strong> - способ доставки,</p>
					<p><strong>{full_delivery_address}</strong> - адрес доставки,</p>
          <p><strong>{track_number}</strong> - номер отслеживания</p>
          <p><strong>{tracking_url}</strong> - URL для отслеживания</p>
				</div>
			</div>
			<hr>
		';	
			
		$this->_html .= '
					<div>
						<input class="mail365_button" type="submit" name="save_settings_email_tab_patterns" value="' . $this->l('Сохранить') . '"/>
					</div>
				</fieldset>
			</form>
		</div>';
	}
	
	private function renderImportTab($mail365_api)
	{
		$this->_html .= '<div>';
    
    $shops = Shop::getShops(TRUE);
		
		$contact_groups = $mail365_api->getContactGroups("", "0", "500", "false", "false", "false");
    
    $html_shops = '';
		
		$html_contact_groups = '';
    
    foreach ($shops as $shop) {
      $html_shops .= '<option value="' . $shop['id_shop'] . '">' . $shop['name'] . '</option>';
    }
		
		foreach ($contact_groups["items"] as $contact_group) {
			$html_contact_groups .= '<option value="' . $contact_group["id"] . '">' . $contact_group["name"] . '</option>';
		}
		
		$this->_html .= '
			<form action="' .$_SERVER['REQUEST_URI']. '" method="post">
				<fieldset>
					<legend>' . $this->l('Импорт контактов') . '</legend>
          <label for="mail365_import_shops">' . $this->l('Импортировать контакты из магазина') . '</label>
          <div class="item_form_settings settings_import">
            <select name="mail365_import_id_shop">
              ' . $html_shops . '
            </select>
          </div>
					<label for="mail365_import">' . $this->l('в группу') . '</label>
					<div class="item_form_settings settings_import">
						<select name="mail365_import_contact_group">
							' . $html_contact_groups . '
						</select>
					</div>
					<div class="item_form_settings settings_import">
						<input class="mail365_button" type="submit" name="import_contacts" value="' . $this->l('Импортировать') . '"/>
					</div>
				</fieldset>
			</form>
      <div class="mail365__alert-info alert alert-info">
        Если у Вас возникают проблемы при добавлении контактов через модуль, выгрузите их в .csv файл и загрузите файл в нашем личном кабинете.
      </div>
      ';
		
		$this->_html .= '</div>';
	}
	
	private function renderAutoImportTab($mail365_api)
	{
    $shops = Shop::getShops(TRUE);
    
		$this->_html .= '<div>';
		
		$contact_groups = $mail365_api->getContactGroups("", "0", "500", "false", "false", "false");
		
		$html_contact_groups = '';
    
    $form_inner = '';
    
    $mail365_autoimport_contact_groups = Tools::jsonDecode(Configuration::get('mail365_autoimport_contact_groups'), TRUE);
		
		foreach ($shops as $shop) {
      $form_inner .= '<div class="form-group">
                        <label>Из магазина ' . $shop['name'] . ' в группу </label>  
                        <div class="item_form_settings settings_autoimport">
						              <select name="mail365_autoimport_contact_groups[' . $shop['id_shop'] . ']">';
      
      foreach ($contact_groups["items"] as $contact_group) {
  			if ($contact_group["id"] == $mail365_autoimport_contact_groups[$shop['id_shop']]) {
  				$form_inner .=     '<option value="' . $contact_group["id"] . '" selected>' . $contact_group["name"] . '</option>';
  			} else {
  				$form_inner .=     '<option value="' . $contact_group["id"] . '">' . $contact_group["name"] . '</option>';
  			}
  		}
        				              
			$form_inner	.=		  '</select>
					              </div>
                      </div>';
    }  
		
		$this->_html .= '
			<form action="' .$_SERVER['REQUEST_URI']. '" method="post">
				<fieldset>
					<legend>' . $this->l('Автоматическое добавление контактов') . '</legend>
					<div style="margin-bottom: 10px; font-size: 12px; font-style: italic; color: #A9A9A9">Контакты будут автоматически добавлять после успешной регистрации клиента</div>
					' . $form_inner . '
          <div class="form-group">
  					<div class="item_form_settings settings_autoimport">
  						<input class="mail365_button" type="submit" name="autoimport_contacts" value="' . $this->l('Сохранить настройки') . '"/>
  					</div>
          </div>
				</fieldset>
			</form>';
		
		$this->_html .= '</div>';
	}
	
	public function hooknewOrder($info) 
	{
		$mail365_api_key = Configuration::get('mail365_api_key');	
		
		if (isset($mail365_api_key) && !empty($mail365_api_key) && preg_match("/^[A-Za-z0-9-]{3}-[A-Za-z0-9-]{12}$/", $mail365_api_key)) {
			
			$mail365_sms_patterns = Tools::jsonDecode(Configuration::get('mail365_sms_patterns'), TRUE);

			$sms_pattern = $mail365_sms_patterns["sms_new"];
			
			$sms_pattern = trim($sms_pattern);

			if (Tools::strlen($sms_pattern) != 0) {	
				$sms_pattern = $this->insertVariableNewOrder($sms_pattern, $info);
							
				$sender_id = Configuration::get('mail365_sender_id');
				$phone = $this->getPhoneNewOrder($info);

				if (!empty($phone) && !empty($phone)) {
			
					$mail365_api = new Mail365API($mail365_api_key);
				
					$mail365_send_time = Configuration::get('mail365_send_time');
					if ($mail365_send_time == 'NULL') {
						$send_date_time = '';
						$use_recepient_time_zone = 'false';
					} else {
						$send_time = (int)$mail365_send_time;
						$send_day = date('Y-m-d');	

						if(date('G') >= $send_time) { //не ошибиться с часовым поясом 
							$send_day = date('Y-m-d',strtotime("+1 day", strtotime($send_day))); 
						}	
						
						$send_time = $send_time - 3; // отправить в API надо в UTC, значит -3 часа
						$send_time = max($send_time, 0); //время должно быть >=0 

						if ($send_time < 10) {
							$send_time = "0" . $send_time;
						}

						$send_date_time = $send_day . "T" . $send_time . ":00:00.00Z";
						$use_recepient_time_zone = 'true';
					}
					$res = $mail365_api->postSingleSms($sender_id, $send_date_time, $use_recepient_time_zone, $phone, $sms_pattern);
				}
			}
			
			$mail365_email_patterns = Tools::jsonDecode(Configuration::get('mail365_email_patterns'), TRUE);
			
			$email_pattern = $mail365_email_patterns["email_new"];
			
			$email_pattern = trim($email_pattern);
	
			if (Tools::strlen($email_pattern) != 0) {
			
				$email_pattern = html_entity_decode($email_pattern);
			
				$email_pattern = $this->insertVariableNewOrder($email_pattern, $info);
				
				$subject = trim(Configuration::get('mail365_subject'));
				
				if (Tools::strlen($subject) != 0) {
				
					$subject = $this->insertVariableNewOrder($subject, $info);
				
					$from_address = trim(Configuration::get('mail365_email_address'));
					
					$to_address = trim($this->getToAddress($info));
        
					if (!empty($from_address) && !empty($to_address)) {
		
						$mail365_api = new Mail365API($mail365_api_key);

						$res = $mail365_api->postSingleEmail($subject, $email_pattern, $from_address, $to_address);
					}
				}
			}
		}
	}
	
	public function hookupdateOrderStatus($new_order_status_id) 
	{
		$mail365_api_key = Configuration::get('mail365_api_key');	
		
		if (isset($mail365_api_key) && !empty($mail365_api_key) && preg_match("/^[A-Za-z0-9-]{3}-[A-Za-z0-9-]{12}$/", $mail365_api_key)) {
			$mail365_sms_patterns = Tools::jsonDecode(Configuration::get('mail365_sms_patterns'), TRUE);

			$sms_pattern = $mail365_sms_patterns["sms_" . $new_order_status_id["newOrderStatus"]->id];
      
      $current_status = (!empty($new_order_status_id["newOrderStatus"]->name)) ? 
                        $new_order_status_id["newOrderStatus"]->name : 
                        $statuses[(new Order($info["id_order"]))->current_state]['name'];

			$sms_pattern = trim($sms_pattern);

			if (Tools::strlen($sms_pattern) != 0) {			
		
				$sms_pattern = $this->insertVariable($sms_pattern, $new_order_status_id);
			
				$sender_id = Configuration::get('mail365_sender_id');

				$phone = $this->getPhone($new_order_status_id);

				if (!empty($phone) && !empty($phone)) {
			
					$mail365_api = new Mail365API($mail365_api_key);
					$mail365_send_time = Configuration::get('mail365_send_time');

					if ($mail365_send_time == 'NULL') {
						$send_date_time = '';
						$use_recepient_time_zone = 'false';
					} else {
						$send_time = (int)$mail365_send_time;
						$send_day = date('Y-m-d');	

						if(date('G') >= $send_time) { //не ошибиться с часовым поясом 
							$send_day = date('Y-m-d',strtotime("+1 day", strtotime($send_day))); 
						}	
						
						$send_time = $send_time - 3; // отправить в API надо в UTC, значит -3 часа
						$send_time = max($send_time, 0); //время должно быть >=0 

						if ($send_time < 10) {
							$send_time = "0" . $send_time;
						}

						$send_date_time = $send_day . "T" . $send_time . ":00:00.00Z";
						$use_recepient_time_zone = 'true';
					}
          	
					$res = $mail365_api->postSingleSms($sender_id, $send_date_time, $use_recepient_time_zone, $phone, $sms_pattern);									
				} else {

        }
			} else {

      }
			
			$mail365_email_patterns = Tools::jsonDecode(Configuration::get('mail365_email_patterns'), TRUE);

			$email_pattern = $mail365_email_patterns["email_" . $new_order_status_id["newOrderStatus"]->id];

			$email_pattern = trim($email_pattern);

			if (Tools::strlen($email_pattern) != 0) {
			
				$email_pattern = html_entity_decode($email_pattern);

				$email_pattern = $this->insertVariable($email_pattern, $new_order_status_id);

				$subject = trim(Configuration::get('mail365_subject'));

				if (Tools::strlen($subject) != 0) {
				
					$subject = $this->insertVariable($subject, $new_order_status_id);

					$from_address = trim(Configuration::get('mail365_email_address'));

					$to_address = trim($this->getToAddress($new_order_status_id));

					if (!empty($from_address) && !empty($to_address)) {
		
						$mail365_api = new Mail365API($mail365_api_key);
						$res = $mail365_api->postSingleEmail($subject, $email_pattern, $from_address, $to_address);
					} else {
            
          }
				} else {

        } 
			} else {

      }
		}
	}
	
	public function hookcreateAccount($post, $new_customer) 
	{
		$mail365_api_key = Configuration::get('mail365_api_key');	
		
		if (isset($mail365_api_key) && !empty($mail365_api_key) && preg_match("/^[A-Za-z0-9-]{3}-[A-Za-z0-9-]{12}$/", $mail365_api_key)) {
			if ($post['_POST']['newsletter']) {
				$birthday = $post["_POST"]["years"] . '-';
				$birthday .= (Tools::strlen($post["_POST"]["months"]) == 1) ? ('0' . $post["_POST"]["months"] . '-') : ($post["_POST"]["months"] . '-');
				$birthday .= (Tools::strlen($post["_POST"]["days"]) == 1) ? ('0' . $post["_POST"]["days"]) : ($post["_POST"]["days"]);
				$data = array(
					"Фамилия" => $post['_POST']['customer_lastname'], 
					"Имя" => $post['_POST']['customer_firstname'], 
					"Электронная почта" => $post["_POST"]["email"],
					"Дата рождения" => $birthday
				);
        
        $mail365_autoimport_contact_groups = Tools::jsonDecode(Configuration::get('mail365_autoimport_contact_groups'), TRUE);
				
				$contact_group_id = $mail365_autoimport_contact_groups[$post['newCustomer']->id_shop];

				if (isset($contact_group_id) && !empty($contact_group_id)) {
				
					$mail365_api = new Mail365API($mail365_api_key);
					
					$res = $mail365_api->postContactGroupsIdContacts($contact_group_id, $data);	
				}
			}	
		}
	}	
  
  public function hookactionPaymentConfirmation ($info)
  {
    $mail365_api_key = Configuration::get('mail365_api_key');	
		
		if (isset($mail365_api_key) && !empty($mail365_api_key) && preg_match("/^[A-Za-z0-9-]{3}-[A-Za-z0-9-]{12}$/", $mail365_api_key)) {

			$mail365_sms_patterns = Tools::jsonDecode(Configuration::get('mail365_sms_patterns'), TRUE);
			
			$sms_pattern = $mail365_sms_patterns["sms_payment_confirm"];
			
			$sms_pattern = trim($sms_pattern);
			
			if (Tools::strlen($sms_pattern) != 0) {			
		
				$sms_pattern = $this->insertVariable($sms_pattern, $info);
							
				$sender_id = Configuration::get('mail365_sender_id');
				$phone = $this->getPhone($info);
				
				if (!empty($phone) && !empty($phone)) {
			
					$mail365_api = new Mail365API($mail365_api_key);
				
					$mail365_send_time = Configuration::get('mail365_send_time');
					if ($mail365_send_time == 'NULL') {
						$send_date_time = '';
						$use_recepient_time_zone = 'false';
					} else {
						$send_time = (int)$mail365_send_time;
						$send_day = date('Y-m-d');	

						if(date('G') >= $send_time) { //не ошибиться с часовым поясом 
							$send_day = date('Y-m-d',strtotime("+1 day", strtotime($send_day))); 
						}	
						
						$send_time = $send_time - 3; // отправить в API надо в UTC, значит -3 часа
						$send_time = max($send_time, 0); //время должно быть >=0 

						if ($send_time < 10) {
							$send_time = "0" . $send_time;
						}

						$send_date_time = $send_day . "T" . $send_time . ":00:00.00Z";
						$use_recepient_time_zone = 'true';
					}
					
					$res = $mail365_api->postSingleSms($sender_id, $send_date_time, $use_recepient_time_zone, $phone, $sms_pattern);					
				}
			}
			
			$mail365_email_patterns = Tools::jsonDecode(Configuration::get('mail365_email_patterns'), TRUE);
			
			$email_pattern = $mail365_email_patterns["email_payment_confirm"];
			
			$email_pattern = trim($email_pattern);
	
			if (Tools::strlen($email_pattern) != 0) {
			
				$email_pattern = html_entity_decode($email_pattern);
			
				$email_pattern = $this->insertVariable($email_pattern, $info);
				
				$subject = trim(Configuration::get('mail365_subject'));
				
				if (Tools::strlen($subject) != 0) {
				
					$subject = $this->insertVariable($subject, $info);
				
					$from_address = trim(Configuration::get('mail365_email_address'));
					
					$to_address = trim($this->getToAddress($info));
				
					if (!empty($from_address) && !empty($to_address)) {
		
						$mail365_api = new Mail365API($mail365_api_key);
					
						$res = $mail365_api->postSingleEmail($subject, $email_pattern, $from_address, $to_address);
					}
				}
			}
		}
  }
  
  public function hookactionAdminOrdersTrackingNumberUpdate ($info)
  {
    $info['id_order'] = $info['order']->id;
    
    $mail365_api_key = Configuration::get('mail365_api_key');	
		
		if (isset($mail365_api_key) && !empty($mail365_api_key) && preg_match("/^[A-Za-z0-9-]{3}-[A-Za-z0-9-]{12}$/", $mail365_api_key)) {
			$mail365_sms_patterns = Tools::jsonDecode(Configuration::get('mail365_sms_patterns'), TRUE);

			$sms_pattern = $mail365_sms_patterns["sms_admin_orders_tracking_number_update"];

			$sms_pattern = trim($sms_pattern);

			if (Tools::strlen($sms_pattern) != 0) {			
		
				$sms_pattern = $this->insertVariable($sms_pattern, $info);
		
				$sender_id = Configuration::get('mail365_sender_id');

				$phone = $this->getPhone($info);

				if (!empty($phone) && !empty($phone)) {
        
					$mail365_api = new Mail365API($mail365_api_key);

					$mail365_send_time = Configuration::get('mail365_send_time');

					if ($mail365_send_time == 'NULL') {
						$send_date_time = '';
						$use_recepient_time_zone = 'false';
					} else {
						$send_time = (int)$mail365_send_time;
						$send_day = date('Y-m-d');	

						if(date('G') >= $send_time) { //не ошибиться с часовым поясом 
							$send_day = date('Y-m-d',strtotime("+1 day", strtotime($send_day))); 
						}	
						
						$send_time = $send_time - 3; // отправить в API надо в UTC, значит -3 часа
						$send_time = max($send_time, 0); //время должно быть >=0 

						if ($send_time < 10) {
							$send_time = "0" . $send_time;
						}

						$send_date_time = $send_day . "T" . $send_time . ":00:00.00Z";
						$use_recepient_time_zone = 'true';
					}

					$res = $mail365_api->postSingleSms($sender_id, $send_date_time, $use_recepient_time_zone, $phone, $sms_pattern);
				} else {

        }
			} else {

      }
			
			$mail365_email_patterns = Tools::jsonDecode(Configuration::get('mail365_email_patterns'), TRUE);
      	
			$email_pattern = $mail365_email_patterns["email_admin_orders_tracking_number_update"];

			$email_pattern = trim($email_pattern);

			if (Tools::strlen($email_pattern) != 0) {
			
				$email_pattern = html_entity_decode($email_pattern);

				$email_pattern = $this->insertVariable($email_pattern, $info);

				$subject = trim(Configuration::get('mail365_subject'));

				if (Tools::strlen($subject) != 0) {
				
					$subject = $this->insertVariable($subject, $info);

					$from_address = trim(Configuration::get('mail365_email_address'));

					$to_address = trim($this->getToAddress($info));

					if (!empty($from_address) && !empty($to_address)) {
		
						$mail365_api = new Mail365API($mail365_api_key);
						$res = $mail365_api->postSingleEmail($subject, $email_pattern, $from_address, $to_address);
					} else {
            
          }
				} else {

        }
			} else {

      }
		}
  }
	
	private function insertVariableNewOrder($pattern, $info)
	{   
		$address = new Address((int)$info["order"]->id_address_delivery);
		$currency = new Currency($info["order"]->id_currency);
		$carrier = new Carrier($info["order"]->id_carrier);
    $shop = new Shop($info["order"]->id_shop);

		if (preg_match("/{date}/", $pattern)) {
      $pattern = preg_replace("/{date}/", date('Y-m-d', strtotime($info["order"]->date_add)), $pattern);
		}

		if (preg_match("/{order}/", $pattern)) {
			$pattern = preg_replace("/{order}/", $info["order"]->id, $pattern);
		}
		
		if (preg_match("/{sum}/", $pattern)) {
			$pattern = preg_replace("/{sum}/", round($info["order"]->total_paid, 2) . " " . $currency->sign, $pattern);
		}
		
		if (preg_match("/{user_name}/", $pattern)) {
			$pattern = preg_replace("/{user_name}/", $address->firstname, $pattern);
		}
		
		if (preg_match("/{status}/", $pattern)) {
			$pattern = preg_replace("/{status}/", 'новый', $pattern);
		}
		
		if (preg_match("/{delivery_description}/", $pattern)) {
			$pattern = preg_replace("/{delivery_description}/", $carrier->name, $pattern);
		}
		
		if (preg_match("/{full_delivery_address}/", $pattern)) {
			$full_delivery_address = '';
			$full_delivery_address .= (isset($address->country) && !empty($address->country)) ? ($address->country . ', ') : '';
			$full_delivery_address .= (isset($address->city) && !empty($address->city)) ? (' г.' . $address->city . ', ') : '';
			$full_delivery_address .= (isset($address->address1) && !empty($address->address1)) ? $address->address1 : '';
			$full_delivery_address = trim($full_delivery_address);
			$pattern = preg_replace("/{full_delivery_address}/", $full_delivery_address, $pattern);
		}
    
    if (preg_match("/{shop_name}/", $pattern)) {
			$pattern = preg_replace("/{shop_name}/", $shop->name, $pattern);
		}
    
    if (preg_match("/{track_number}/", $pattern)) {
      $pattern = preg_replace("/{track_number}/", $info["order"]->shipping_number, $pattern); 
    }
    
    if (preg_match("/{order_reference}/", $pattern)) {
      $pattern = preg_replace("/{order_reference}/", $info["order"]->reference, $pattern); 
    }
		
		return $pattern;
	}
	
	private function insertVariable($pattern, $info)
	{
    $order = new Order($info["id_order"]);  
		$address = new Address((int)$order->id_address_delivery);
		$currency = new Currency($order->id_currency);
		$delivery = new Delivery($order->id_carrier);
		$carrier = new Carrier($order->id_carrier);

    $shop = new Shop($order->id_shop);
    
    $statuses = OrderState::getOrderStates($order->id_lang);
				
		if (preg_match("/{date}/", $pattern)) {
      $pattern = preg_replace("/{date}/", date('Y-m-d', strtotime($order->date_add)), $pattern);
		}
		
		if (preg_match("/{order}/", $pattern)) {
			$pattern = preg_replace("/{order}/", $order->id, $pattern);
		}
		
		if (preg_match("/{sum}/", $pattern)) {
			$pattern = preg_replace("/{sum}/", round($order->total_paid, 2) . " " . $currency->sign, $pattern);
		}
		
		if (preg_match("/{user_name}/", $pattern)) {
			$pattern = preg_replace("/{user_name}/", $address->firstname, $pattern);
		}
		
		if (preg_match("/{status}/", $pattern)) {
      $current_status = '';
      
      if (!empty($info["newOrderStatus"]->name)) {
        $current_status = $info["newOrderStatus"]->name;
      } else {
        $status_keys = array_search($order->current_state, array_column($statuses, 'id_order_state'));
        $current_status = $statuses[$status_keys]['name'];
      }
      
			$pattern = preg_replace("/{status}/", $current_status, $pattern);
		}
		
		if (preg_match("/{delivery_description}/", $pattern)) {
			$pattern = preg_replace("/{delivery_description}/", $carrier->name, $pattern);
		}
		
		if (preg_match("/{full_delivery_address}/", $pattern)) {
			$full_delivery_address = '';
			$full_delivery_address .= (isset($address->country) && !empty($address->country)) ? ($address->country . ', ') : '';
			$full_delivery_address .= (isset($address->city) && !empty($address->city)) ? (' г.' . $address->city . ', ') : '';
			$full_delivery_address .= (isset($address->address1) && !empty($address->address1)) ? $address->address1 : '';
			$full_delivery_address = trim($full_delivery_address);
			$pattern = preg_replace("/{full_delivery_address}/", $full_delivery_address, $pattern);
		}
    
    if (preg_match("/{shop_name}/", $pattern)) {
			$pattern = preg_replace("/{shop_name}/", $shop->name, $pattern);
		}
    
    if (preg_match("/{track_number}/", $pattern)) {
      $pattern = preg_replace("/{track_number}/", $order->shipping_number, $pattern); 
    }
    
    if (preg_match("/{tracking_url}/", $pattern)) {      
      $url_pattern = $carrier->url;
      $url = preg_replace('/@/', $order->shipping_number, $url_pattern);
      
      if (!empty($url)) 
        $pattern = preg_replace("/{tracking_url}/", $url, $pattern); 
    }
    
    if (preg_match("/{order_reference}/", $pattern)) {
      $pattern = preg_replace("/{order_reference}/", $order->reference, $pattern); 
    }

		return $pattern;		
	}
	
	private function getPhone($info) 
	{
    $order = new Order($info["id_order"]);  
		$address = new Address((int)$order->id_address_delivery);
		$country = new Country((int)$address->id_country);

    $phone = '';
		
    if (!empty($address->phone)) {
      $phone = $address->phone;
    } else {
      if (Tools::strlen((string)$address->phone_mobile) == 11) {
        $phone = $address->phone_mobile;
  		} else {
  			$phone = $country->call_prefix . $address->phone_mobile;
		  }
    }

    return $phone;
	}
	
	private function getPhoneNewOrder($info) 
	{
		$address = new Address($info["order"]->id_address_delivery);

		return (!empty($address->phone)) ? $address->phone : $address->phone_mobile;
	}
	
	private function getToAddress($info) 
	{
    if (!empty($info["id_order"])) {
      $order = new Order($info["id_order"]);
		  $customer = new Customer($order->id_customer);
    } else {
      $customer = new Customer($info["order"]->id_customer);
    }

		return $customer->email;
	}
		
	private function importContacts($id_shop, $contact_group_id)
	{
	
		$mail365_api_key = Configuration::get('mail365_api_key');	
		
		if (isset($mail365_api_key) && !empty($mail365_api_key) && preg_match("/^[A-Za-z0-9-]{3}-[A-Za-z0-9-]{12}$/", $mail365_api_key)) {
	
			$prestashop_contact = $this->getNewsletterEmails(true, $id_shop);
			
			$result = array(
				"error" => 0,
				"all_contacts" => count($prestashop_contact),
				"phones" => array(),
				"emails" => array(),
			);
		
			$for_request = array();
			$for_duplicate = array();
			
			$cmh = curl_multi_init();
									
			for ($i = 0; $i < count($prestashop_contact); $i++) {
				$ch = curl_init('https://api.mail365.ru/contactGroups/' . $contact_group_id . '/contacts');
				$for_request[$i]['handle'] = $ch;
				$for_request[$i]['post_data'] = array(
					"Фамилия" => $prestashop_contact[$i]["lastname"], 
					"Имя" => $prestashop_contact[$i]["firstname"], 
					"Электронная почта" => $prestashop_contact[$i]["email"]
				);
				if (!empty($prestashop_contact[$i]["phone_mobile"])) {
					$for_request[$i]['post_data']["Номер телефона"] = $prestashop_contact[$i]["phone_mobile"];
				}
				curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
				curl_setopt($ch, CURLOPT_POST, 1);  
	  
				curl_setopt($ch, CURLOPT_HTTPHEADER, array(  
						'Accept: application/json',  
						'Content-Type: application/json',  
						'Authorization: ApiKey ' . $mail365_api_key
					)
				);  

				curl_setopt($ch, CURLOPT_POSTFIELDS, Tools::jsonEncode(
						array(
							'Data' => $for_request[$i]["post_data"]
						)
					)
				);  
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
		
				curl_multi_add_handle($cmh, $ch);
			}
			
			$active = null;
			do {
				$mrc = curl_multi_exec($cmh, $active);

				if ($state = curl_multi_info_read($cmh)) {
					$info = curl_getinfo($state['handle']);
					if ($info["http_code"] == 409) {
						$res = curl_multi_getcontent($state['handle']);
						$res = Tools::jsonDecode($res, TRUE);
						for ($i = 0; $i < count($for_request); $i++) {
							if ($for_request[$i]['handle'] === $state['handle']) {
								$request_post_data = $for_request[$i]['post_data'];
								if (strripos($res["message"], 'номер телефона')) {
									$result["error"] = 1;
									if (array_search($request_post_data['Номер телефона'], $result["phones"]) === FALSE) {
										$result["phones"][] = $request_post_data['Номер телефона'];
									}
									unset($request_post_data["Номер телефона"]);
								}
								if (strripos($res["message"], 'email')) {
									$result["error"] = 1;
									if (array_search($request_post_data['Электронная почта'], $result["emails"]) === FALSE) {
										$result["emails"][] = $request_post_data['Электронная почта'];
									}
									unset($request_post_data["Электронная почта"]);
								}
								$for_duplicate[]['post_data'] = $request_post_data;
							}
						}
					}
					curl_multi_remove_handle($cmh, $state['handle']);
				}

				//usleep(10); // stop wasting CPU cycles and rest for a couple ms

			} while ($mrc == CURLM_CALL_MULTI_PERFORM || $active);
	 
			// закрываем мультикурл
			curl_multi_close($cmh);
			
			if ($result["error"]) {
				$mail365_api = new Mail365API($mail365_api_key);
				for ($i = 0; $i < count($for_duplicate); $i++) {
					if (array_key_exists('Номер телефона', $for_duplicate[$i]["post_data"]) || array_key_exists('Электронная почта', $for_duplicate[$i]["post_data"])) {
						$res = $mail365_api->postContactGroupsIdContacts($contact_group_id, $for_duplicate[$i]['post_data']);
						if ($res["http_code"] == 409) {
							if (strripos($res["message"], 'номер телефона')) {
								$result["error"] = 1;
								if (array_search($for_duplicate[$i]['post_data']['Номер телефона'], $result["phones"]) === FALSE) {
									$result["phones"][] = $for_duplicate[$i]['post_data']['Номер телефона'];
								}
							}
							if (strripos($res["message"], 'email')) {
								$result["error"] = 1;
								if (array_search($for_duplicate[$i]['post_data']['Электронная почта'], $result["emails"]) === FALSE) {
									$result["emails"][] = $for_duplicate[$i]['post_data']['Электронная почта'];
								}
							}
						}
					}
				}
			}
		}
		
		return $result;
	}
	
	private function getNewsletterEmails ($is_newsletter = true, $id_shop = null)
	{
		return Db::getInstance(_PS_USE_SQL_SLAVE_)->ExecuteS('
		SELECT c.`id_customer`, c.`email`, c.`firstname`, c.`lastname`, c.`newsletter`, c.`ip_registration_newsletter`, c.`newsletter_date_add`, a.`phone_mobile`
		FROM `'._DB_PREFIX_.'customer` c
		LEFT JOIN `'._DB_PREFIX_.'address` a ON (c.`id_customer` = a.`id_customer` AND a.`deleted` = 0 AND a.`active` = 1)
		WHERE '.($is_newsletter?'c.`newsletter` = 1 AND ':'') . (!empty($id_shop) ? 'c.`id_shop` = ' . $id_shop . ' AND ' : '') . 'c.`active` = 1
		GROUP BY c.`id_customer`');
	}
	
	private function trueWordFormBe ($num) 
	{
		if ($num == 1) return 'был';
	
		return 'было';
	}
	
	private function trueWordFormImport ($num)
	{
		if ($num == 1) return 'импортирован';
	
		return 'импортировано';
	}
	
	private function trueWordFormContacts ($num) 
	{
		$num = abs($num) % 100; // берем число по модулю и сбрасываем сотни (делим на 100, а остаток присваиваем переменной $num)
		$num_x = $num % 10; // сбрасываем десятки и записываем в новую переменную

		if ($num > 10 && $num < 20) // если число принадлежит отрезку [11;19]
			return 'контактов';
			
		if ($num_x > 1 && $num_x < 5) // иначе если число оканчивается на 2,3,4
			return 'контакта';
			
		if ($num_x == 1) // иначе если оканчивается на 1
			return 'контакт';
			
		return 'контактов';
	}
  
  private function sendPostRequest ($URL, $post_data) 
  {
			
		$ch = curl_init();

		curl_setopt($ch, CURLOPT_URL, $URL);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_POST, 1);  
  
 		
		curl_setopt($ch, CURLOPT_POSTFIELDS, Tools::jsonEncode($post_data));  
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
		
    $response = curl_exec ($ch);  
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		
		curl_close ($ch); 
	}
}